@@ -58,12 +58,8 @@ backupLabelFormat(const BackupType type, const String *const backupLabelPrior, c
     ASSERT(timestamp > 0);
 
     // Format the timestamp
-    struct tm timePart;
     char buffer[DATE_TIME_LEN + 1];
-
-    THROW_ON_SYS_ERROR(
-        strftime(buffer, sizeof(buffer), "%Y%m%d-%H%M%S", localtime_r(&timestamp, &timePart)) == 0, AssertError,
-        "unable to format time");
+    cvtTimeToZP("%Y%m%d-%H%M%S", timestamp, buffer, sizeof(buffer));
 
     // If full label
     String *result;
