@@ -48,12 +48,10 @@ restoreFile(
     ASSERT(repoFile != NULL);
 
     // Restore file results
-    List *result = NULL;
+    List *const result = lstNewP(sizeof(RestoreFileResult));
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        result = lstNewP(sizeof(RestoreFileResult));
-
         // Check files to determine which ones need to be restored
         for (unsigned int fileIdx = 0; fileIdx < lstSize(fileList); fileIdx++)
         {
@@ -88,8 +86,10 @@ restoreFile(
                         // Else use size and checksum
                         else
                         {
-                            // Only continue delta if the file size is as expected or larger
-                            if (info.size >= file->size || file->blockIncrMapSize != 0)
+                            // Only continue delta if the file size is as expected or larger (for normal files) or if block
+                            // incremental and the file to delta is not zero-length. Block incremental can potentially use almost
+                            // any portion of an existing file, but of course zero-length files do not have anything to reuse.
+                            if (info.size >= file->size || (file->blockIncrMapSize != 0 && info.size != 0))
                             {
                                 const char *const fileName = strZ(storagePathP(storagePg(), file->name));
 
@@ -193,7 +193,7 @@ restoreFile(
                 if (fileResult->result == restoreResultCopy && (file->size == 0 || file->zero))
                 {
                     // Create destination file
-                    StorageWrite *pgFileWrite = storageNewWriteP(
+                    StorageWrite *const pgFileWrite = storageNewWriteP(
                         storagePgWrite(), file->name, .modeFile = file->mode, .user = file->user, .group = file->group,
                         .timeModified = file->timeModified, .noAtomic = true, .noCreatePath = true, .noSyncPath = true);
 
@@ -241,29 +241,24 @@ restoreFile(
                             ASSERT(varUInt64(file->limit) != 0);
                             repoFileLimit = varUInt64(file->limit);
 
-                            // Multiple files cannot be read when the file to read is a block incremental. This is because the
-                            // remote protocol does not support multiple open files at once.
-                            if (file->blockIncrMapSize == 0)
+                            // Determine how many files can be copied with one read
+                            for (unsigned int fileNextIdx = fileIdx + 1; fileNextIdx < lstSize(fileList); fileNextIdx++)
                             {
-                                // Determine how many files can be copied with one read
-                                for (unsigned int fileNextIdx = fileIdx + 1; fileNextIdx < lstSize(fileList); fileNextIdx++)
+                                // Only files that are being copied are considered
+                                if (((const RestoreFileResult *)lstGet(result, fileNextIdx))->result == restoreResultCopy)
                                 {
-                                    // Only files that are being copied are considered
-                                    if (((const RestoreFileResult *)lstGet(result, fileNextIdx))->result == restoreResultCopy)
-                                    {
-                                        const RestoreFile *const fileNext = lstGet(fileList, fileNextIdx);
-                                        ASSERT(fileNext->limit != NULL && varUInt64(fileNext->limit) != 0);
+                                    const RestoreFile *const fileNext = lstGet(fileList, fileNextIdx);
+                                    ASSERT(fileNext->limit != NULL && varUInt64(fileNext->limit) != 0);
 
-                                        // Break if the offset is not the first file's offset + limit of all additional files so far
-                                        if (fileNext->offset != file->offset + repoFileLimit)
-                                            break;
-
-                                        repoFileLimit += varUInt64(fileNext->limit);
-                                    }
-                                    // Else if the file was not copied then there is a gap so break
-                                    else
+                                    // Break if the offset is not the first file's offset + limit of all additional files so far
+                                    if (fileNext->offset != file->offset + repoFileLimit)
                                         break;
+
+                                    repoFileLimit += varUInt64(fileNext->limit);
                                 }
+                                // Else if the file was not copied then there is a gap so break
+                                else
+                                    break;
                             }
                         }
 
@@ -282,7 +277,7 @@ restoreFile(
                     }
 
                     // Create pg file
-                    StorageWrite *pgFileWrite = storageNewWriteP(
+                    StorageWrite *const pgFileWrite = storageNewWriteP(
                         storagePgWrite(), file->name, .modeFile = file->mode, .user = file->user, .group = file->group,
                         .timeModified = file->timeModified, .noAtomic = true, .noCreatePath = true, .noSyncPath = true,
                         .noTruncate = file->blockChecksum != NULL);
@@ -310,9 +305,6 @@ restoreFile(
                         const BlockMap *const blockMap = blockMapNewRead(
                             blockMapRead, file->blockIncrSize, file->blockIncrChecksumSize);
 
-                        // The repo file needs to be closed so that block lists can be read from the remote protocol
-                        ioReadClose(storageReadIo(repoFileRead));
-
                         // Open file to write
                         ioWriteOpen(storageWriteIo(pgFileWrite));
 
@@ -376,7 +368,7 @@ restoreFile(
                     // Else normal file
                     else
                     {
-                        IoFilterGroup *filterGroup = ioWriteFilterGroup(storageWriteIo(pgFileWrite));
+                        IoFilterGroup *const filterGroup = ioWriteFilterGroup(storageWriteIo(pgFileWrite));
 
                         // Add decryption filter
                         if (cipherPass != NULL)
@@ -425,8 +417,6 @@ restoreFile(
             }
             MEM_CONTEXT_TEMP_END();
         }
-
-        lstMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
