@@ -246,7 +246,7 @@ FN_EXTERN size_t typeToLog(const char *typeName, char *buffer, size_t bufferSize
 #define FUNCTION_LOG_TIME_TYPE                                                                                                     \
     time_t
 #define FUNCTION_LOG_TIME_FORMAT(value, buffer, bufferSize)                                                                        \
-    cvtTimeToZ(value, buffer, bufferSize)
+    cvtTimeToZP("%s", value, buffer, bufferSize)
 
 #define FUNCTION_LOG_UINT_TYPE                                                                                                     \
     unsigned int
@@ -335,6 +335,7 @@ Macros to return function results (or void)
 #define FUNCTION_LOG_RETURN_VOID()                                                                                                 \
     do                                                                                                                             \
     {                                                                                                                              \
+        FUNCTION_TEST_MEM_CONTEXT_AUDIT_END("void");                                                                               \
         STACK_TRACE_POP(false);                                                                                                    \
                                                                                                                                    \
         LOG(FUNCTION_LOG_LEVEL(), 0, "=> void");                                                                                   \
@@ -445,8 +446,8 @@ Ignore DEBUG_TEST_TRACE_MACRO if DEBUG is not defined because the underlying fun
     {                                                                                                                              \
         (void)FUNCTION_TEST_BEGIN_exists; /* CHECK for presence of FUNCTION_TEST_BEGIN*() */                                       \
                                                                                                                                    \
-        STACK_TRACE_POP(true);                                                                                                     \
         FUNCTION_TEST_MEM_CONTEXT_AUDIT_END("void");                                                                               \
+        STACK_TRACE_POP(true);                                                                                                     \
         return;                                                                                                                    \
     }                                                                                                                              \
     while (0)
