@@ -81,7 +81,7 @@ ioFilterGroupNew(void)
 
 /**********************************************************************************************************************************/
 FN_EXTERN IoFilterGroup *
-ioFilterGroupAdd(IoFilterGroup *this, IoFilter *filter)
+ioFilterGroupAdd(IoFilterGroup *const this, IoFilter *const filter)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
@@ -104,7 +104,7 @@ ioFilterGroupAdd(IoFilterGroup *this, IoFilter *filter)
 
 /**********************************************************************************************************************************/
 FN_EXTERN IoFilterGroup *
-ioFilterGroupInsert(IoFilterGroup *this, unsigned int listIdx, IoFilter *filter)
+ioFilterGroupInsert(IoFilterGroup *const this, const unsigned int listIdx, IoFilter *const filter)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
@@ -129,7 +129,7 @@ ioFilterGroupInsert(IoFilterGroup *this, unsigned int listIdx, IoFilter *filter)
 Get a filter
 ***********************************************************************************************************************************/
 static IoFilterData *
-ioFilterGroupGet(const IoFilterGroup *this, unsigned int filterIdx)
+ioFilterGroupGet(const IoFilterGroup *const this, const unsigned int filterIdx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(IO_FILTER_GROUP, this);
@@ -143,7 +143,7 @@ ioFilterGroupGet(const IoFilterGroup *this, unsigned int filterIdx)
 
 /**********************************************************************************************************************************/
 FN_EXTERN IoFilterGroup *
-ioFilterGroupClear(IoFilterGroup *this)
+ioFilterGroupClear(IoFilterGroup *const this)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
@@ -164,7 +164,7 @@ ioFilterGroupClear(IoFilterGroup *this)
 Setup the filter group and allocate any required buffers
 ***********************************************************************************************************************************/
 FN_EXTERN void
-ioFilterGroupOpen(IoFilterGroup *this)
+ioFilterGroupOpen(IoFilterGroup *const this)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
@@ -187,7 +187,7 @@ ioFilterGroupOpen(IoFilterGroup *this)
 
         for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
         {
-            IoFilterData *filterData = ioFilterGroupGet(this, filterIdx);
+            IoFilterData *const filterData = ioFilterGroupGet(this, filterIdx);
 
             // If there is no last output buffer yet, then use the input buffer that will be provided by the caller
             if (lastOutputBuffer == NULL)
@@ -225,7 +225,7 @@ ioFilterGroupOpen(IoFilterGroup *this)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
+ioFilterGroupProcess(IoFilterGroup *const this, const Buffer *const input, Buffer *const output)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
@@ -285,7 +285,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
         // new input for the first filter.
         for (; filterIdx < ioFilterGroupSize(this); filterIdx++)
         {
-            IoFilterData *filterData = ioFilterGroupGet(this, filterIdx);
+            IoFilterData *const filterData = ioFilterGroupGet(this, filterIdx);
 
             // Process the filter if it is not done
             if (!ioFilterDone(filterData->filter))
@@ -331,7 +331,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 
     for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
     {
-        IoFilterData *filterData = ioFilterGroupGet(this, filterIdx);
+        const IoFilterData *const filterData = ioFilterGroupGet(this, filterIdx);
 
         // When inputSame then this->pub.done = false and we can exit the loop immediately
         if (ioFilterInputSame(filterData->filter))
@@ -363,7 +363,7 @@ ioFilterGroupClose(IoFilterGroup *this)
     // Gather results from the filters
     for (unsigned int filterIdx = 0; filterIdx < ioFilterGroupSize(this); filterIdx++)
     {
-        IoFilter *const filter = ioFilterGroupGet(this, filterIdx)->filter;
+        const IoFilter *const filter = ioFilterGroupGet(this, filterIdx)->filter;
 
         MEM_CONTEXT_BEGIN(lstMemContext(this->filterResult))
         {
@@ -382,7 +382,7 @@ ioFilterGroupClose(IoFilterGroup *this)
 
 /**********************************************************************************************************************************/
 FN_EXTERN Pack *
-ioFilterGroupParamAll(const IoFilterGroup *this)
+ioFilterGroupParamAll(const IoFilterGroup *const this)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_FILTER_GROUP, this);
