@@ -25,11 +25,13 @@ STRING_EXTERN(HTTP_VERB_POST_STR,                                   HTTP_VERB_PO
 STRING_EXTERN(HTTP_VERB_PUT_STR,                                    HTTP_VERB_PUT);
 
 STRING_EXTERN(HTTP_HEADER_AUTHORIZATION_STR,                        HTTP_HEADER_AUTHORIZATION);
+STRING_EXTERN(HTTP_HEADER_CONTENT_ID_STR,                           HTTP_HEADER_CONTENT_ID);
 STRING_EXTERN(HTTP_HEADER_CONTENT_LENGTH_STR,                       HTTP_HEADER_CONTENT_LENGTH);
 STRING_EXTERN(HTTP_HEADER_CONTENT_MD5_STR,                          HTTP_HEADER_CONTENT_MD5);
 STRING_EXTERN(HTTP_HEADER_CONTENT_RANGE_STR,                        HTTP_HEADER_CONTENT_RANGE);
 STRING_EXTERN(HTTP_HEADER_CONTENT_TYPE_STR,                         HTTP_HEADER_CONTENT_TYPE);
 STRING_EXTERN(HTTP_HEADER_CONTENT_TYPE_APP_FORM_URL_STR,            HTTP_HEADER_CONTENT_TYPE_APP_FORM_URL);
+STRING_EXTERN(HTTP_HEADER_CONTENT_TYPE_HTTP_STR,                    HTTP_HEADER_CONTENT_TYPE_HTTP);
 STRING_EXTERN(HTTP_HEADER_CONTENT_TYPE_JSON_STR,                    HTTP_HEADER_CONTENT_TYPE_JSON);
 STRING_EXTERN(HTTP_HEADER_CONTENT_TYPE_XML_STR,                     HTTP_HEADER_CONTENT_TYPE_XML);
 STRING_EXTERN(HTTP_HEADER_ETAG_STR,                                 HTTP_HEADER_ETAG);
@@ -39,9 +41,6 @@ STRING_EXTERN(HTTP_HEADER_LAST_MODIFIED_STR,                        HTTP_HEADER_
 STRING_EXTERN(HTTP_HEADER_RANGE_STR,                                HTTP_HEADER_RANGE);
 #define HTTP_HEADER_USER_AGENT                                      "user-agent"
 
-// 5xx errors that should always be retried
-#define HTTP_RESPONSE_CODE_RETRY_CLASS                              5
-
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
@@ -54,11 +53,69 @@ struct HttpRequest
     HttpSession *session;                                           // Session for async requests
 };
 
+struct HttpRequestMulti
+{
+    List *contentList;                                              // Multipart content
+    size_t contentSize;                                             // Size of all content (excluding boundaries)
+    Buffer *boundaryRaw;                                            // Multipart boundary (not yet formatted for output)
+};
+
+/***********************************************************************************************************************************
+Format the request (excluding content)
+***********************************************************************************************************************************/
+static String *
+httpRequestFmt(
+    const String *const verb, const String *const path, const HttpQuery *const query, const HttpHeader *const header,
+    const bool agent)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, verb);
+        FUNCTION_TEST_PARAM(STRING, path);
+        FUNCTION_TEST_PARAM(HTTP_QUERY, query);
+        FUNCTION_TEST_PARAM(HTTP_HEADER, header);
+        FUNCTION_TEST_PARAM(BOOL, agent);
+    FUNCTION_TEST_END();
+
+    ASSERT(verb != NULL);
+    ASSERT(path != NULL);
+    ASSERT(header != NULL);
+
+    String *const result = strNew();
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Add verb, path, and query
+        strCatFmt(
+            result, "%s %s%s%s " HTTP_VERSION "\r\n", strZ(verb), strZ(path), query == NULL ? "" : "?",
+            query == NULL ? "" : strZ(httpQueryRenderP(query)));
+
+        // Add user agent
+        if (agent)
+            strCatZ(result, HTTP_HEADER_USER_AGENT ":" PROJECT_NAME "/" PROJECT_VERSION "\r\n");
+
+        // Add headers
+        StringList *const headerList = httpHeaderList(header);
+
+        for (unsigned int headerIdx = 0; headerIdx < strLstSize(headerList); headerIdx++)
+        {
+            const String *const headerKey = strLstGet(headerList, headerIdx);
+
+            strCatFmt(result, "%s:%s\r\n", strZ(headerKey), strZ(httpHeaderGet(header, headerKey)));
+        }
+
+        // Add blank line to end of headers
+        strCat(result, CRLF_STR);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN(STRING, result);
+}
+
 /***********************************************************************************************************************************
 Process the request
 ***********************************************************************************************************************************/
 static HttpResponse *
-httpRequestProcess(HttpRequest *this, bool waitForResponse, bool contentCache)
+httpRequestProcess(HttpRequest *const this, const bool waitForResponse, const bool contentCache)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(HTTP_REQUEST, this);
@@ -75,7 +132,7 @@ httpRequestProcess(HttpRequest *this, bool waitForResponse, bool contentCache)
     {
         bool retry;
         ErrorRetry *const errRetry = errRetryNew();
-        Wait *wait = waitNew(httpClientTimeout(this->client));
+        Wait *const wait = waitNew(httpClientTimeout(this->client));
 
         do
         {
@@ -99,28 +156,13 @@ httpRequestProcess(HttpRequest *this, bool waitForResponse, bool contentCache)
                     {
                         session = httpClientOpen(this->client);
 
-                        // Format the request and user agent
-                        String *requestStr =
-                            strCatFmt(
-                                strNew(),
-                                "%s %s%s%s " HTTP_VERSION "\r\n" HTTP_HEADER_USER_AGENT ":" PROJECT_NAME "/" PROJECT_VERSION "\r\n",
-                                strZ(httpRequestVerb(this)), strZ(httpRequestPath(this)), httpRequestQuery(this) == NULL ? "" : "?",
-                                httpRequestQuery(this) == NULL ? "" : strZ(httpQueryRenderP(httpRequestQuery(this))));
-
-                        // Add headers
-                        const StringList *headerList = httpHeaderList(httpRequestHeader(this));
-
-                        for (unsigned int headerIdx = 0; headerIdx < strLstSize(headerList); headerIdx++)
-                        {
-                            const String *headerKey = strLstGet(headerList, headerIdx);
-
-                            strCatFmt(
-                                requestStr, "%s:%s\r\n", strZ(headerKey), strZ(httpHeaderGet(httpRequestHeader(this), headerKey)));
-                        }
-
-                        // Add blank line to end of headers and write the request as a buffer so secrets do not show up in logs
-                        strCat(requestStr, CRLF_STR);
-                        ioWrite(httpSessionIoWrite(session), BUFSTR(requestStr));
+                        // Write the request as a buffer so secrets do not show up in logs
+                        ioWrite(
+                            httpSessionIoWrite(session),
+                            BUFSTR(
+                                httpRequestFmt(
+                                    httpRequestVerb(this), httpRequestPath(this), httpRequestQuery(this), httpRequestHeader(this),
+                                    true)));
 
                         // Write out content if any
                         if (this->content != NULL)
@@ -142,7 +184,7 @@ httpRequestProcess(HttpRequest *this, bool waitForResponse, bool contentCache)
                         // Retry when response code is 5xx. These errors generally represent a server error for a request that looks
                         // valid. There are a few errors that might be permanently fatal but they are rare and it seems best not to
                         // try and pick and choose errors in this class to retry.
-                        if (httpResponseCode(result) / 100 == HTTP_RESPONSE_CODE_RETRY_CLASS)
+                        if (httpResponseCodeRetry(result))
                             THROW_FMT(ServiceError, "[%u] %s", httpResponseCode(result), strZ(httpResponseReason(result)));
 
                         // Move response to outer temp context
@@ -181,7 +223,7 @@ httpRequestProcess(HttpRequest *this, bool waitForResponse, bool contentCache)
 
 /**********************************************************************************************************************************/
 FN_EXTERN HttpRequest *
-httpRequestNew(HttpClient *client, const String *verb, const String *path, HttpRequestNewParam param)
+httpRequestNew(HttpClient *const client, const String *const verb, const String *const path, const HttpRequestNewParam param)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(HTTP_CLIENT, client);
@@ -221,7 +263,7 @@ httpRequestNew(HttpClient *client, const String *verb, const String *path, HttpR
 
 /**********************************************************************************************************************************/
 FN_EXTERN HttpResponse *
-httpRequestResponse(HttpRequest *this, bool contentCache)
+httpRequestResponse(HttpRequest *const this, const bool contentCache)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(HTTP_REQUEST, this);
@@ -235,7 +277,7 @@ httpRequestResponse(HttpRequest *this, bool contentCache)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-httpRequestError(const HttpRequest *this, HttpResponse *response)
+httpRequestError(const HttpRequest *const this, HttpResponse *const response)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(HTTP_REQUEST, this);
@@ -246,7 +288,7 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
     ASSERT(response != NULL);
 
     // Error code
-    String *error = strCatFmt(strNew(), "HTTP request failed with %u", httpResponseCode(response));
+    String *const error = strCatFmt(strNew(), "HTTP request failed with %u", httpResponseCode(response));
 
     // Add reason when present
     if (strSize(httpResponseReason(response)) > 0)
@@ -261,7 +303,7 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
         strCatFmt(error, "?%s", strZ(httpQueryRenderP(httpRequestQuery(this), .redact = true)));
 
     // Output request headers
-    const StringList *requestHeaderList = httpHeaderList(httpRequestHeader(this));
+    const StringList *const requestHeaderList = httpHeaderList(httpRequestHeader(this));
 
     if (!strLstEmpty(requestHeaderList))
     {
@@ -269,7 +311,7 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
 
         for (unsigned int requestHeaderIdx = 0; requestHeaderIdx < strLstSize(requestHeaderList); requestHeaderIdx++)
         {
-            const String *key = strLstGet(requestHeaderList, requestHeaderIdx);
+            const String *const key = strLstGet(requestHeaderList, requestHeaderIdx);
 
             strCatFmt(
                 error, "\n%s: %s", strZ(key),
@@ -278,8 +320,8 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
     }
 
     // Output response headers
-    const HttpHeader *responseHeader = httpResponseHeader(response);
-    const StringList *responseHeaderList = httpHeaderList(responseHeader);
+    const HttpHeader *const responseHeader = httpResponseHeader(response);
+    const StringList *const responseHeaderList = httpHeaderList(responseHeader);
 
     if (!strLstEmpty(responseHeaderList))
     {
@@ -287,7 +329,7 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
 
         for (unsigned int responseHeaderIdx = 0; responseHeaderIdx < strLstSize(responseHeaderList); responseHeaderIdx++)
         {
-            const String *key = strLstGet(responseHeaderList, responseHeaderIdx);
+            const String *const key = strLstGet(responseHeaderList, responseHeaderIdx);
             strCatFmt(error, "\n%s: %s", strZ(key), strZ(httpHeaderGet(responseHeader, key)));
         }
     }
@@ -302,6 +344,161 @@ httpRequestError(const HttpRequest *this, HttpResponse *response)
     THROW(ProtocolError, strZ(error));
 }
 
+/**********************************************************************************************************************************/
+#define HTTP_MULTIPART_BOUNDARY_INIT_SIZE                           (sizeof(HTTP_MULTIPART_BOUNDARY_INIT) - 1)
+
+FN_EXTERN HttpRequestMulti *
+httpRequestMultiNew(void)
+{
+    FUNCTION_TEST_VOID();
+
+    OBJ_NEW_BEGIN(HttpRequestMulti, .childQty = MEM_CONTEXT_QTY_MAX)
+    {
+        *this = (HttpRequestMulti)
+        {
+            .boundaryRaw = bufNewC(HTTP_MULTIPART_BOUNDARY_INIT, HTTP_MULTIPART_BOUNDARY_INIT_SIZE),
+            .contentList = lstNewP(sizeof(Buffer *)),
+        };
+    }
+    OBJ_NEW_END();
+
+    FUNCTION_TEST_RETURN(HTTP_REQUEST_MULTI, this);
+}
+
+/**********************************************************************************************************************************/
+#define HTTP_MULTIPART_BOUNDARY_EXTRA_SIZE                          (sizeof(HTTP_MULTIPART_BOUNDARY_EXTRA) - 1)
+
+FN_EXTERN void
+httpRequestMultiAdd(
+    HttpRequestMulti *const this, const String *const contentId, const String *const verb, const String *const path,
+    const HttpRequestNewParam param)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(HTTP_REQUEST_MULTI, this);
+        FUNCTION_TEST_PARAM(STRING, contentId);
+        FUNCTION_TEST_PARAM(STRING, verb);
+        FUNCTION_TEST_PARAM(STRING, path);
+        FUNCTION_TEST_PARAM(HTTP_QUERY, param.query);
+        FUNCTION_TEST_PARAM(HTTP_HEADER, param.header);
+        FUNCTION_TEST_PARAM(BUFFER, param.content);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(contentId != NULL);
+    ASSERT(verb != NULL);
+    ASSERT(path != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Construct request header
+        String *const request = strNew();
+
+        strCatZ(request, HTTP_HEADER_CONTENT_TYPE ":" HTTP_HEADER_CONTENT_TYPE_HTTP "\r\n");
+        strCatZ(request, HTTP_HEADER_CONTENT_TRANSFER_ENCODING ":" HTTP_HEADER_CONTENT_TRANSFER_ENCODING_BINARY "\r\n");
+        strCatFmt(request, HTTP_HEADER_CONTENT_ID ":%s\r\n\r\n", strZ(contentId));
+        strCat(request, httpRequestFmt(verb, path, param.query, param.header, false));
+
+        MEM_CONTEXT_OBJ_BEGIN(this->contentList)
+        {
+            // Add content
+            Buffer *const content = bufNew(strSize(request) + (param.content == NULL ? 0 : bufUsed(param.content)));
+
+            bufCat(content, BUFSTR(request));
+            bufCat(content, param.content);
+
+            // Find a boundary that is not used in the content
+            while (bufFindP(content, this->boundaryRaw) != NULL)
+            {
+                if (bufUsed(this->boundaryRaw) == HTTP_MULTIPART_BOUNDARY_INIT_SIZE + HTTP_MULTIPART_BOUNDARY_EXTRA_SIZE)
+                    THROW(AssertError, "unable to construct unique boundary");
+
+                bufCatC(
+                    this->boundaryRaw, (unsigned char *)HTTP_MULTIPART_BOUNDARY_EXTRA,
+                    bufUsed(this->boundaryRaw) - HTTP_MULTIPART_BOUNDARY_INIT_SIZE, HTTP_MULTIPART_BOUNDARY_NEXT);
+            }
+
+            // Add to list
+            lstAdd(this->contentList, &content);
+            this->contentSize += bufUsed(content);
+        }
+        MEM_CONTEXT_OBJ_END();
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+#define HTTP_MULTIPART_BOUNDARY_PRE_SIZE                            (sizeof(HTTP_MULTIPART_BOUNDARY_PRE) - 1)
+#define HTTP_MULTIPART_BOUNDARY_POST_SIZE                           (sizeof(HTTP_MULTIPART_BOUNDARY_POST) - 1)
+#define HTTP_MULTIPART_BOUNDARY_POST_LAST_SIZE                      (sizeof(HTTP_MULTIPART_BOUNDARY_POST_LAST) - 1)
+
+FN_EXTERN Buffer *
+httpRequestMultiContent(HttpRequestMulti *const this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(HTTP_REQUEST_MULTI, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(!lstEmpty(this->contentList));
+
+    const size_t boundarySize = bufUsed(this->boundaryRaw) + HTTP_MULTIPART_BOUNDARY_PRE_SIZE;
+    Buffer *const result = bufNew(
+        this->contentSize + (lstSize(this->contentList) * (boundarySize + HTTP_MULTIPART_BOUNDARY_POST_SIZE)) +
+        HTTP_MULTIPART_BOUNDARY_POST_LAST_SIZE);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Generate boundary
+        Buffer *const boundary = bufNew(boundarySize);
+        bufCat(boundary, BUFSTRDEF(HTTP_MULTIPART_BOUNDARY_PRE));
+        bufCat(boundary, this->boundaryRaw);
+
+        // Add first boundary
+        bufCat(result, boundary);
+        bufCat(result, BUFSTRDEF(HTTP_MULTIPART_BOUNDARY_POST));
+
+        // Add content and boundaries
+        for (unsigned int contentIdx = 0; contentIdx < lstSize(this->contentList); contentIdx++)
+        {
+            bufCat(result, *(Buffer **)lstGet(this->contentList, contentIdx));
+            bufCat(result, boundary);
+
+            if (contentIdx < lstSize(this->contentList) - 1)
+                bufCat(result, BUFSTRDEF(HTTP_MULTIPART_BOUNDARY_POST));
+            else
+                bufCat(result, BUFSTRDEF(HTTP_MULTIPART_BOUNDARY_POST_LAST));
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN(BUFFER, result);
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN HttpHeader *
+httpRequestMultiHeaderAdd(HttpRequestMulti *const this, HttpHeader *const header)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(HTTP_REQUEST_MULTI, this);
+        FUNCTION_TEST_PARAM(HTTP_HEADER, header);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(header != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        httpHeaderAdd(
+            header, HTTP_HEADER_CONTENT_TYPE_STR,
+            strNewFmt(HTTP_HEADER_CONTENT_TYPE_MULTIPART "%s", strZ(strNewBuf(this->boundaryRaw))));
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN(HTTP_HEADER, header);
+}
+
 /**********************************************************************************************************************************/
 FN_EXTERN void
 httpRequestToLog(const HttpRequest *const this, StringStatic *const debugLog)
