@@ -394,14 +394,14 @@ memContextAuditAllocExtraName(void *const allocExtra, const char *const name)
 Wrapper around malloc() with error handling
 ***********************************************************************************************************************************/
 static void *
-memAllocInternal(size_t size)
+memAllocInternal(const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
     // Allocate memory
-    void *buffer = malloc(size);
+    void *const buffer = malloc(size);
 
     // Error when malloc fails
     if (buffer == NULL)
@@ -415,14 +415,14 @@ memAllocInternal(size_t size)
 Allocate an array of pointers and set all entries to NULL
 ***********************************************************************************************************************************/
 static void *
-memAllocPtrArrayInternal(size_t size)
+memAllocPtrArrayInternal(const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
     // Allocate memory
-    void **buffer = memAllocInternal(size * sizeof(void *));
+    void **const buffer = memAllocInternal(size * sizeof(void *));
 
     // Set all pointers to NULL
     for (size_t ptrIdx = 0; ptrIdx < size; ptrIdx++)
@@ -436,7 +436,7 @@ memAllocPtrArrayInternal(size_t size)
 Wrapper around realloc() with error handling
 ***********************************************************************************************************************************/
 static void *
-memReAllocInternal(void *bufferOld, size_t sizeNew)
+memReAllocInternal(void *const bufferOld, const size_t sizeNew)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, bufferOld);
@@ -446,7 +446,7 @@ memReAllocInternal(void *bufferOld, size_t sizeNew)
     ASSERT(bufferOld != NULL);
 
     // Allocate memory
-    void *bufferNew = realloc(bufferOld, sizeNew);
+    void *const bufferNew = realloc(bufferOld, sizeNew);
 
     // Error when realloc fails
     if (bufferNew == NULL)
@@ -460,7 +460,7 @@ memReAllocInternal(void *bufferOld, size_t sizeNew)
 Wrapper around realloc() with error handling
 ***********************************************************************************************************************************/
 static void *
-memReAllocPtrArrayInternal(void *bufferOld, size_t sizeOld, size_t sizeNew)
+memReAllocPtrArrayInternal(void *const bufferOld, const size_t sizeOld, const size_t sizeNew)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, bufferOld);
@@ -469,7 +469,7 @@ memReAllocPtrArrayInternal(void *bufferOld, size_t sizeOld, size_t sizeNew)
     FUNCTION_TEST_END();
 
     // Allocate memory
-    void **bufferNew = memReAllocInternal(bufferOld, sizeNew * sizeof(void *));
+    void **const bufferNew = memReAllocInternal(bufferOld, sizeNew * sizeof(void *));
 
     // Set all new pointers to NULL
     for (size_t ptrIdx = sizeOld; ptrIdx < sizeNew; ptrIdx++)
@@ -483,7 +483,7 @@ memReAllocPtrArrayInternal(void *bufferOld, size_t sizeOld, size_t sizeNew)
 Wrapper around free()
 ***********************************************************************************************************************************/
 static void
-memFreeInternal(void *buffer)
+memFreeInternal(void *const buffer)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, buffer);
@@ -676,7 +676,7 @@ memContextFromAllocExtra(void *const allocExtra)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *callbackArgument)
+memContextCallbackSet(MemContext *const this, void (*const callbackFunction)(void *), void *const callbackArgument)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
@@ -705,7 +705,7 @@ memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-memContextCallbackClear(MemContext *this)
+memContextCallbackClear(MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
@@ -778,7 +778,7 @@ memContextAllocNew(const size_t size)
             if (contextAlloc->freeIdx == contextAlloc->listSize)
             {
                 // Calculate new list size
-                unsigned int listSizeNew = contextAlloc->listSize * 2;
+                const unsigned int listSizeNew = contextAlloc->listSize * 2;
 
                 // Reallocate memory before modifying anything else in case there is an error
                 contextAlloc->list = memReAllocPtrArrayInternal(contextAlloc->list, contextAlloc->listSize, listSizeNew);
@@ -805,7 +805,7 @@ memContextAllocNew(const size_t size)
 Resize memory that has already been allocated
 ***********************************************************************************************************************************/
 static MemContextAlloc *
-memContextAllocResize(MemContextAlloc *alloc, size_t size)
+memContextAllocResize(MemContextAlloc *alloc, const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, alloc);
@@ -839,27 +839,25 @@ memContextAllocResize(MemContextAlloc *alloc, size_t size)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void *
-memNew(size_t size)
+memNew(const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    void *result = MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size));
-
-    FUNCTION_TEST_RETURN_P(VOID, result);
+    FUNCTION_TEST_RETURN_P(VOID, MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size)));
 }
 
 /**********************************************************************************************************************************/
 FN_EXTERN void *
-memNewPtrArray(size_t size)
+memNewPtrArray(const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
     // Allocate pointer array
-    void **buffer = (void **)MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size * sizeof(void *)));
+    void **const buffer = (void **const)MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size * sizeof(void *)));
 
     // Set pointers to NULL
     for (size_t ptrIdx = 0; ptrIdx < size; ptrIdx++)
@@ -870,7 +868,7 @@ memNewPtrArray(size_t size)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void *
-memResize(const void *buffer, size_t size)
+memResize(const void *const buffer, const size_t size)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, buffer);
@@ -923,7 +921,7 @@ memFree(void *const buffer)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-memContextMove(MemContext *this, MemContext *parentNew)
+memContextMove(MemContext *const this, MemContext *const parentNew)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
@@ -984,7 +982,7 @@ memContextMove(MemContext *this, MemContext *parentNew)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-memContextSwitch(MemContext *this)
+memContextSwitch(MemContext *const this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
