@@ -8,6 +8,7 @@ Protocol Server
 Object type
 ***********************************************************************************************************************************/
 typedef struct ProtocolServer ProtocolServer;
+typedef struct ProtocolServerResult ProtocolServerResult;
 
 #include "common/io/read.h"
 #include "common/io/write.h"
@@ -22,42 +23,55 @@ Protocol command handler type and structure
 An array of this struct must be passed to protocolServerProcess() for the server to process commands. Each command handler should
 implement a single command, as defined by the command string.
 ***********************************************************************************************************************************/
-typedef void (*ProtocolServerCommandHandler)(PackRead *param, ProtocolServer *server);
+typedef ProtocolServerResult *(*ProtocolServerCommandOpenHandler)(PackRead *param);
+typedef ProtocolServerResult *(*ProtocolServerCommandProcessHandler)(PackRead *param);
+typedef ProtocolServerResult *(*ProtocolServerCommandProcessSessionHandler)(PackRead *param, void *sessionData);
+typedef ProtocolServerResult *(*ProtocolServerCommandCloseHandler)(PackRead *param, void *sessionData);
 
 typedef struct ProtocolServerHandler
 {
     StringId command;                                               // 5-bit StringId that identifies the protocol command
-    ProtocolServerCommandHandler handler;                           // Function that handles the protocol command
+    ProtocolServerCommandOpenHandler open;                          // Function that opens the protocol session
+    ProtocolServerCommandProcessHandler process;                    // Function that processes the protocol command
+    ProtocolServerCommandProcessSessionHandler processSession;      // Function that processes the protocol command for a session
+    ProtocolServerCommandCloseHandler close;                        // Function that closes the protocol session
 } ProtocolServerHandler;
 
 /***********************************************************************************************************************************
-Constructors
+Server Constructors
 ***********************************************************************************************************************************/
 FN_EXTERN ProtocolServer *protocolServerNew(const String *name, const String *service, IoRead *read, IoWrite *write);
 
 /***********************************************************************************************************************************
-Functions
+Server Functions
 ***********************************************************************************************************************************/
 // Get command from the client. Outside ProtocolServer, this is used when the first noop command needs to be processed before
 // running protocolServerProcess(), which allows an error to be returned to the client if initialization fails.
-typedef struct ProtocolServerCommandGetResult
+typedef struct ProtocolServerRequestResult
 {
     StringId id;                                                    // Command identifier
+    ProtocolCommandType type;                                       // Command type
+    bool sessionRequired;                                           // Session with more than one command
     Pack *param;                                                    // Parameter pack
-} ProtocolServerCommandGetResult;
+} ProtocolServerRequestResult;
 
-FN_EXTERN ProtocolServerCommandGetResult protocolServerCommandGet(ProtocolServer *this);
+FN_EXTERN ProtocolServerRequestResult protocolServerRequest(ProtocolServer *this);
 
-// Get data from the client
-FN_EXTERN PackRead *protocolServerDataGet(ProtocolServer *this);
+// Send response to client
+typedef struct ProtocolServerResponseParam
+{
+    VAR_PARAM_HEADER;
+    bool close;                                                     // Has the session been closed?
+    ProtocolMessageType type;                                       // Message type
+    PackWrite *data;                                                // Response data
+} ProtocolServerResponseParam;
 
-// Put data to the client
-FN_EXTERN void protocolServerDataPut(ProtocolServer *this, PackWrite *data);
+#define protocolServerResponseP(this, ...)                                                                                         \
+    protocolServerResponse(this, (ProtocolServerResponseParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-// Put data end to the client. This ends command processing and no more data should be sent.
-FN_EXTERN void protocolServerDataEndPut(ProtocolServer *this);
+FN_EXTERN void protocolServerResponse(ProtocolServer *const this, ProtocolServerResponseParam param);
 
-// Return an error
+// Send an error to client
 FN_EXTERN void protocolServerError(ProtocolServer *this, int code, const String *message, const String *stack);
 
 // Process requests
@@ -73,7 +87,7 @@ protocolServerMove(ProtocolServer *const this, MemContext *const parentNew)
 }
 
 /***********************************************************************************************************************************
-Destructor
+Server Destructor
 ***********************************************************************************************************************************/
 FN_INLINE_ALWAYS void
 protocolServerFree(ProtocolServer *const this)
@@ -81,6 +95,32 @@ protocolServerFree(ProtocolServer *const this)
     objFree(this);
 }
 
+/***********************************************************************************************************************************
+Result Constructors
+***********************************************************************************************************************************/
+typedef struct ProtocolServerResultNewParam
+{
+    VAR_PARAM_HEADER;
+    size_t extra;
+} ProtocolServerResultNewParam;
+
+#define protocolServerResultNewP(...)                                                                                              \
+    protocolServerResultNew((ProtocolServerResultNewParam){VAR_PARAM_INIT, __VA_ARGS__})
+
+FN_EXTERN ProtocolServerResult *protocolServerResultNew(ProtocolServerResultNewParam param);
+
+/***********************************************************************************************************************************
+Result Getters/Setters
+***********************************************************************************************************************************/
+// Create PackWrite object required to send data to the client
+FN_EXTERN PackWrite *protocolServerResultData(ProtocolServerResult *this);
+
+// Set session data
+FN_EXTERN void protocolServerResultSessionDataSet(ProtocolServerResult *const this, void *const sessionData);
+
+// Close session
+FN_EXTERN void protocolServerResultCloseSet(ProtocolServerResult *const this);
+
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
@@ -91,4 +131,11 @@ FN_EXTERN void protocolServerToLog(const ProtocolServer *this, StringStatic *deb
 #define FUNCTION_LOG_PROTOCOL_SERVER_FORMAT(value, buffer, bufferSize)                                                             \
     FUNCTION_LOG_OBJECT_FORMAT(value, protocolServerToLog, buffer, bufferSize)
 
+FN_EXTERN void protocolServerResultToLog(const ProtocolServerResult *this, StringStatic *debugLog);
+
+#define FUNCTION_LOG_PROTOCOL_SERVER_RESULT_TYPE                                                                                   \
+    ProtocolServerResult *
+#define FUNCTION_LOG_PROTOCOL_SERVER_RESULT_FORMAT(value, buffer, bufferSize)                                                      \
+    FUNCTION_LOG_OBJECT_FORMAT(value, protocolServerResultToLog, buffer, bufferSize)
+
 #endif
