@@ -20,6 +20,7 @@ struct StorageList
     Blob *blob;                                                     // Blob of info data
     String *name;                                                   // Current info name
     String *linkDestination;                                        // Current link destination
+    String *versionId;                                              // Current version id
 };
 
 /***********************************************************************************************************************************
@@ -34,7 +35,8 @@ typedef struct StorageListInfo
         const char *name;                                           // Name of path/file/link
     } exists;
 
-    // Mode is only provided at detail level but is included here to save space on 64-bit architectures
+    // Set when info type >= storageInfoLevelType (undefined at lower levels). Mode is only provided at higher detail levels but
+    // included here to save space on 64-bit architectures
     struct
     {
         // Set when info type >= storageInfoLevelType (undefined at lower levels)
@@ -49,6 +51,7 @@ typedef struct StorageListInfo
     {
         uint64_t size;                                              // Size (path/link is 0)
         time_t timeModified;                                        // Time file was last modified
+        const char *versionId;                                      // Version id when versioning enabled
     } basic;
 
     // Set when info type >= storageInfoLevelDetail (undefined at lower levels)
@@ -95,6 +98,7 @@ storageLstNew(const StorageInfoLevel level)
             .blob = blbNew(),
             .name = strNew(),
             .linkDestination = strNew(),
+            .versionId = strNew(),
         };
     }
     OBJ_NEW_END();
@@ -137,9 +141,14 @@ storageLstInsert(StorageList *const this, const unsigned int idx, const StorageI
             }
 
             case storageInfoLevelBasic:
+            {
                 listInfo.basic.size = info->size;
                 listInfo.basic.timeModified = info->timeModified;
 
+                if (info->versionId != NULL)
+                    listInfo.basic.versionId = blbAdd(this->blob, strZ(info->versionId), strSize(info->versionId) + 1);
+            }
+
             case storageInfoLevelType:
                 listInfo.type.type = info->type;
 
@@ -156,7 +165,7 @@ storageLstInsert(StorageList *const this, const unsigned int idx, const StorageI
 
 /**********************************************************************************************************************************/
 FN_EXTERN StorageInfo
-storageLstGet(StorageList *const this, const unsigned int idx)
+storageLstGet(const StorageList *const this, const unsigned int idx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STORAGE_LIST, this);
@@ -189,9 +198,14 @@ storageLstGet(StorageList *const this, const unsigned int idx)
         }
 
         case storageInfoLevelBasic:
+        {
             result.size = listInfo->basic.size;
             result.timeModified = listInfo->basic.timeModified;
 
+            if (listInfo->basic.versionId != NULL)
+                result.versionId = strCatZ(strTrunc(this->versionId), listInfo->basic.versionId);
+        }
+
         case storageInfoLevelType:
             result.type = listInfo->type.type;
 
@@ -202,6 +216,27 @@ storageLstGet(StorageList *const this, const unsigned int idx)
     FUNCTION_TEST_RETURN(STORAGE_INFO, result);
 }
 
+/**********************************************************************************************************************************/
+FN_EXTERN StorageInfo
+storageLstFind(const StorageList *const this, const String *const name)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STORAGE_LIST, this);
+        FUNCTION_TEST_PARAM(STRING, name);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(name != NULL);
+
+    const char *const namePtr = strZ(name);
+    const unsigned int listIdx = lstFindIdx(this->pub.list, &namePtr);
+
+    if (listIdx == LIST_NOT_FOUND)
+        FUNCTION_TEST_RETURN(STORAGE_INFO, (StorageInfo){.exists = false});
+
+    FUNCTION_TEST_RETURN(STORAGE_INFO, storageLstGet(this, listIdx));
+}
+
 /**********************************************************************************************************************************/
 FN_EXTERN void
 storageLstToLog(const StorageList *const this, StringStatic *const debugLog)
