@@ -14,7 +14,6 @@ Object type
 struct StorageRead
 {
     StorageReadPub pub;                                             // Publicly accessible variables
-    void *driver;                                                   // Driver
 };
 
 /***********************************************************************************************************************************
@@ -39,12 +38,8 @@ storageReadNew(void *const driver, const StorageReadInterface *const interface)
     ASSERT(driver != NULL);
     ASSERT(interface != NULL);
 
-    StorageRead *this = NULL;
-
     OBJ_NEW_BEGIN(StorageRead, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        this = OBJ_NEW_ALLOC();
-
         *this = (StorageRead)
         {
             .pub =
@@ -52,7 +47,6 @@ storageReadNew(void *const driver, const StorageReadInterface *const interface)
                 .interface = interface,
                 .io = ioReadNew(driver, interface->ioInterface),
             },
-            .driver = objMove(driver, objMemContext(this)),
         };
     }
     OBJ_NEW_END();
