@@ -11,7 +11,7 @@ Remote Storage File write
 #include "common/type/object.h"
 #include "storage/remote/protocol.h"
 #include "storage/remote/write.h"
-#include "storage/write.intern.h"
+#include "storage/write.h"
 
 /***********************************************************************************************************************************
 Object type
@@ -22,6 +22,7 @@ typedef struct StorageWriteRemote
     StorageRemote *storage;                                         // Storage that created this object
     StorageWrite *write;                                            // Storage write interface
     ProtocolClient *client;                                         // Protocol client to make requests with
+    ProtocolClientSession *session;                                 // Protocol session for requests
 
 #ifdef DEBUG
     uint64_t protocolWriteBytes;                                    // How many bytes were written to the protocol layer?
@@ -36,30 +37,6 @@ Macros for function logging
 #define FUNCTION_LOG_STORAGE_WRITE_REMOTE_FORMAT(value, buffer, bufferSize)                                                        \
     objNameToLog(value, "StorageWriteRemote", buffer, bufferSize)
 
-/***********************************************************************************************************************************
-Close file on the remote
-***********************************************************************************************************************************/
-static void
-storageWriteRemoteFreeResource(THIS_VOID)
-{
-    THIS(StorageWriteRemote);
-
-    FUNCTION_LOG_BEGIN(logLevelTrace);
-        FUNCTION_LOG_PARAM(STORAGE_WRITE_REMOTE, this);
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-
-    PackWrite *const write = protocolPackNew();
-    protocolClientDataPut(this->client, pckWriteBoolP(write, false));
-    pckWriteFree(write);
-
-    protocolClientDataPut(this->client, NULL);
-    protocolClientDataEndGet(this->client);
-
-    FUNCTION_LOG_RETURN_VOID();
-}
-
 /***********************************************************************************************************************************
 Open the file
 ***********************************************************************************************************************************/
@@ -80,8 +57,7 @@ storageWriteRemoteOpen(THIS_VOID)
         if (this->interface.compressible)
             ioFilterGroupInsert(ioWriteFilterGroup(storageWriteIo(this->write)), 0, decompressFilterP(compressTypeGz));
 
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_OPEN_WRITE);
-        PackWrite *const param = protocolCommandParam(command);
+        PackWrite *const param = protocolPackNew();
 
         pckWriteStrP(param, this->interface.name);
         pckWriteModeP(param, this->interface.modeFile);
@@ -95,8 +71,7 @@ storageWriteRemoteOpen(THIS_VOID)
         pckWriteBoolP(param, this->interface.atomic);
         pckWritePackP(param, ioFilterGroupParamAll(ioWriteFilterGroup(storageWriteIo(this->write))));
 
-        protocolClientCommandPut(this->client, command, true);
-        protocolClientDataGet(this->client);
+        protocolClientSessionOpenP(this->session, .param = param);
 
         // Clear filters since they will be run on the remote side
         ioFilterGroupClear(ioWriteFilterGroup(storageWriteIo(this->write)));
@@ -108,9 +83,6 @@ storageWriteRemoteOpen(THIS_VOID)
                 ioWriteFilterGroup(storageWriteIo(this->write)),
                 compressFilterP(compressTypeGz, (int)this->interface.compressLevel));
         }
-
-        // Set free callback to ensure remote file is freed
-        memContextCallbackSet(objMemContext(this), storageWriteRemoteFreeResource, this);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -121,7 +93,7 @@ storageWriteRemoteOpen(THIS_VOID)
 Write to the file
 ***********************************************************************************************************************************/
 static void
-storageWriteRemote(THIS_VOID, const Buffer *buffer)
+storageWriteRemote(THIS_VOID, const Buffer *const buffer)
 {
     THIS(StorageWriteRemote);
 
@@ -135,8 +107,13 @@ storageWriteRemote(THIS_VOID, const Buffer *buffer)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        protocolClientDataPut(
-            this->client, pckWriteBinP(pckWriteNewP(.size = ioBufferSize() + PROTOCOL_PACK_DEFAULT_SIZE), buffer));
+        if (protocolClientSessionQueued(this->session))
+            protocolClientSessionResponse(this->session);
+
+        PackWrite *const param = pckWriteNewP(.size = PROTOCOL_PACK_DEFAULT_SIZE + bufUsed(buffer));
+        pckWriteBinP(param, buffer);
+
+        protocolClientSessionRequestAsyncP(this->session, .param = param);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -166,15 +143,15 @@ storageWriteRemoteClose(THIS_VOID)
     {
         MEM_CONTEXT_TEMP_BEGIN()
         {
-            protocolClientDataPut(this->client, NULL);
+            if (protocolClientSessionQueued(this->session))
+                protocolClientSessionResponse(this->session);
+
             ioFilterGroupResultAllSet(
-                ioWriteFilterGroup(storageWriteIo(this->write)), pckReadPackP(protocolClientDataGet(this->client)));
-            protocolClientDataEndGet(this->client);
+                ioWriteFilterGroup(storageWriteIo(this->write)), pckReadPackP(protocolClientSessionClose(this->session)));
         }
         MEM_CONTEXT_TEMP_END();
 
         this->client = NULL;
-        memContextCallbackClear(objMemContext(this));
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -183,9 +160,9 @@ storageWriteRemoteClose(THIS_VOID)
 /**********************************************************************************************************************************/
 FN_EXTERN StorageWrite *
 storageWriteRemoteNew(
-    StorageRemote *storage, ProtocolClient *client, const String *name, mode_t modeFile, mode_t modePath, const String *user,
-    const String *group, time_t timeModified, bool createPath, bool syncFile, bool syncPath, bool atomic, bool compressible,
-    unsigned int compressLevel)
+    StorageRemote *const storage, ProtocolClient *const client, const String *const name, const mode_t modeFile,
+    const mode_t modePath, const String *const user, const String *const group, const time_t timeModified, const bool createPath,
+    const bool syncFile, const bool syncPath, const bool atomic, const bool compressible, const unsigned int compressLevel)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_REMOTE, storage);
@@ -215,6 +192,7 @@ storageWriteRemoteNew(
         {
             .storage = storage,
             .client = client,
+            .session = protocolClientSessionNewP(client, PROTOCOL_COMMAND_STORAGE_WRITE, .async = true),
 
             .interface = (StorageWriteInterface)
             {
