@@ -1,5 +1,7 @@
 /***********************************************************************************************************************************
 S3 Storage Read
+
+Based on the documentation at https://cloud.google.com/storage/docs/json_api/v1/objects/get
 ***********************************************************************************************************************************/
 #include "build.auto.h"
 
@@ -7,7 +9,7 @@ S3 Storage Read
 #include "common/io/http/client.h"
 #include "common/log.h"
 #include "common/type/object.h"
-#include "storage/read.intern.h"
+#include "storage/read.h"
 #include "storage/s3/read.h"
 
 /***********************************************************************************************************************************
@@ -49,23 +51,30 @@ storageReadS3Open(THIS_VOID)
 
     bool result = false;
 
-    // Request the file
-    MEM_CONTEXT_OBJ_BEGIN(this)
+    // Read if not versioned or if versionId is not null
+    if (!this->interface.version || this->interface.versionId != NULL)
     {
-        this->httpResponse = storageS3RequestP(
-            this->storage, HTTP_VERB_GET_STR, this->interface.name,
-            .header = httpHeaderPutRange(httpHeaderNew(NULL), this->interface.offset, this->interface.limit),
-            .allowMissing = true, .contentIo = true);
-    }
-    MEM_CONTEXT_OBJ_END();
+        // Request the file
+        MEM_CONTEXT_OBJ_BEGIN(this)
+        {
+            this->httpResponse = storageS3RequestP(
+                this->storage, HTTP_VERB_GET_STR, this->interface.name,
+                .header = httpHeaderPutRange(httpHeaderNew(NULL), this->interface.offset, this->interface.limit),
+                .query =
+                    this->interface.versionId == NULL
+                        ? NULL : httpQueryPut(httpQueryNewP(), STRDEF("versionId"), this->interface.versionId),
+                .allowMissing = true, .contentIo = true, .sseC = true);
+        }
+        MEM_CONTEXT_OBJ_END();
 
-    if (httpResponseCodeOk(this->httpResponse))
-    {
-        result = true;
+        if (httpResponseCodeOk(this->httpResponse))
+        {
+            result = true;
+        }
+        // Else error unless ignore missing
+        else if (!this->interface.ignoreMissing)
+            THROW_FMT(FileMissingError, STORAGE_ERROR_READ_MISSING, strZ(this->interface.name));
     }
-    // Else error unless ignore missing
-    else if (!this->interface.ignoreMissing)
-        THROW_FMT(FileMissingError, STORAGE_ERROR_READ_MISSING, strZ(this->interface.name));
 
     FUNCTION_LOG_RETURN(BOOL, result);
 }
@@ -74,7 +83,7 @@ storageReadS3Open(THIS_VOID)
 Read from a file
 ***********************************************************************************************************************************/
 static size_t
-storageReadS3(THIS_VOID, Buffer *buffer, bool block)
+storageReadS3(THIS_VOID, Buffer *const buffer, const bool block)
 {
     THIS(StorageReadS3);
 
@@ -112,7 +121,8 @@ storageReadS3Eof(THIS_VOID)
 /**********************************************************************************************************************************/
 FN_EXTERN StorageRead *
 storageReadS3New(
-    StorageS3 *const storage, const String *const name, const bool ignoreMissing, const uint64_t offset, const Variant *const limit)
+    StorageS3 *const storage, const String *const name, const bool ignoreMissing, const uint64_t offset, const Variant *const limit,
+    const bool version, const String *const versionId)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_S3, storage);
@@ -120,6 +130,8 @@ storageReadS3New(
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
         FUNCTION_LOG_PARAM(UINT64, offset);
         FUNCTION_LOG_PARAM(VARIANT, limit);
+        FUNCTION_LOG_PARAM(BOOL, version);
+        FUNCTION_LOG_PARAM(STRING, versionId);
     FUNCTION_LOG_END();
 
     ASSERT(storage != NULL);
@@ -139,6 +151,8 @@ storageReadS3New(
                 .ignoreMissing = ignoreMissing,
                 .offset = offset,
                 .limit = varDup(limit),
+                .version = version,
+                .versionId = strDup(versionId),
 
                 .ioInterface = (IoReadInterface)
                 {
