@@ -34,10 +34,10 @@ typedef enum
 Constructors
 ***********************************************************************************************************************************/
 FN_EXTERN Storage *storageS3New(
-    const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
+    const String *path, bool write, time_t targetTime, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
     const String *endPoint, StorageS3UriStyle uriStyle, const String *region, StorageS3KeyType keyType, const String *accessKey,
     const String *secretAccessKey, const String *securityToken, const String *kmsKeyId, const String *sseCustomerKey,
-    const String *credRole, const String *webIdToken, size_t partSize, const KeyValue *tag, const String *host, unsigned int port,
+    const String *credRole, const String *webIdTokenFile, size_t partSize, const KeyValue *tag, const String *host, unsigned int port,
     TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath);
 
 #endif
