@@ -5,43 +5,13 @@ Test Command
 
 #include <stdlib.h>
 
+#include "build/common/exec.h"
 #include "command/test/build.h"
 #include "common/debug.h"
 #include "common/log.h"
 #include "config/config.h"
 #include "storage/posix/storage.h"
 
-/**********************************************************************************************************************************/
-static const String *cmdTestExecLog;
-
-static void
-cmdTestExec(const String *const command)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STRING, command);
-    FUNCTION_LOG_END();
-
-    ASSERT(cmdTestExecLog != NULL);
-    ASSERT(command != NULL);
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        LOG_DETAIL_FMT("exec: %s", strZ(command));
-
-        if (system(zNewFmt("%s > %s 2>&1", strZ(command), strZ(cmdTestExecLog))) != 0)
-        {
-            const Buffer *const buffer = storageGetP(storageNewReadP(storagePosixNewP(FSLASH_STR), cmdTestExecLog));
-
-            THROW_FMT(
-                ExecuteError, "unable to execute: %s > %s 2>&1:\n%s", strZ(command), strZ(cmdTestExecLog),
-                zNewFmt("\n%s", strZ(strTrim(strNewBuf(buffer)))));
-        }
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN_VOID();
-}
-
 /**********************************************************************************************************************************/
 static void
 cmdTestPathCreate(const Storage *const storage, const String *const path)
@@ -55,17 +25,19 @@ cmdTestPathCreate(const Storage *const storage, const String *const path)
 
     ASSERT(storage != NULL);
 
+    const String *const rmCommand = strNewFmt("rm -rf '%s'/*", strZ(storagePathP(storage, path)));
+
     TRY_BEGIN()
     {
-        storagePathRemoveP(storage, path, .recurse = true);
+        execOneP(rmCommand);
     }
     CATCH_ANY()
     {
         // Reset permissions
-        cmdTestExec(strNewFmt("chmod -R 777 %s", strZ(storagePathP(storage, path))));
+        execOneP(strNewFmt("chmod -R 777 '%s'", strZ(storagePathP(storage, path))));
 
         // Try to remove again
-        storagePathRemoveP(storage, path, .recurse = true);
+        execOneP(rmCommand);
     }
     TRY_END();
 
@@ -77,15 +49,17 @@ cmdTestPathCreate(const Storage *const storage, const String *const path)
 /**********************************************************************************************************************************/
 void
 cmdTest(
-    const String *const pathRepo, const String *const pathTest, const String *const vm, const unsigned int vmId,
-    const String *moduleName, const unsigned int test, const uint64_t scale, const LogLevel logLevel, const bool logTime,
-    const String *const timeZone, const bool coverage, const bool profile, const bool optimize, const bool backTrace)
+    const String *const pathRepo, const String *const pathTest, const String *vm, const unsigned int vmId,
+    const String *const pgVersion, const String *moduleName, const unsigned int test, const uint64_t scale, const LogLevel logLevel,
+    const bool logTime, const String *const timeZone, const bool coverage, const bool profile, const bool optimize,
+    const bool backTrace)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, pathRepo);
         FUNCTION_LOG_PARAM(STRING, pathTest);
         FUNCTION_LOG_PARAM(STRING, vm);
         FUNCTION_LOG_PARAM(UINT, vmId);
+        FUNCTION_LOG_PARAM(STRING, pgVersion);
         FUNCTION_LOG_PARAM(STRING, moduleName);
         FUNCTION_LOG_PARAM(UINT, test);
         FUNCTION_LOG_PARAM(UINT64, scale);
@@ -100,9 +74,6 @@ cmdTest(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Log file name
-        cmdTestExecLog = strNewFmt("%s/exec-%u.log", strZ(pathTest), vmId);
-
         // Find test
         ASSERT(moduleName != NULL);
 
@@ -111,6 +82,13 @@ cmdTest(
 
         CHECK_FMT(ParamInvalidError, module != NULL, "'%s' is not a valid test", strZ(moduleName));
 
+        // Vm used for integration and the pgbackrest binary
+        const String *const vmInt = vm;
+
+        // If integration then the vm should be none. Integration tests do not run in containers but instead spawn their own.
+        if (module->type == testDefTypeIntegration)
+            vm = strNewZ("none");
+
         // Build test
         bool buildRetry = false;
         const String *const pathUnit = strNewFmt("%s/unit-%u/%s", strZ(pathTest), vmId, strZ(vm));
@@ -123,8 +101,8 @@ cmdTest(
             {
                 // Build unit
                 TestBuild *const testBld = testBldNew(
-                    pathRepo, pathTest, vm, vmId, module, test, scale, logLevel, logTime, timeZone, coverage, profile, optimize,
-                    backTrace);
+                    pathRepo, pathTest, vm, vmInt, vmId, pgVersion, module, test, scale, logLevel, logTime, timeZone, coverage,
+                    profile, optimize, backTrace);
                 testBldUnit(testBld);
 
                 // Meson setup
@@ -144,9 +122,9 @@ cmdTest(
                 {
                     LOG_DETAIL("meson setup");
 
-                    cmdTestExec(
+                    execOneP(
                         strNewFmt(
-                            "meson setup -Dwerror=true -Dfatal-errors=true %s %s %s", strZ(mesonSetup), strZ(pathUnitBuild),
+                            "meson setup -Dwerror=true -Dfatal-errors=true %s '%s' '%s'", strZ(mesonSetup), strZ(pathUnitBuild),
                             strZ(pathUnit)));
                 }
                 // Else reconfigure
@@ -154,7 +132,7 @@ cmdTest(
                 {
                     LOG_DETAIL("meson configure");
 
-                    cmdTestExec(strNewFmt("meson configure %s %s", strZ(mesonSetup), strZ(pathUnitBuild)));
+                    execOneP(strNewFmt("meson configure %s '%s'", strZ(mesonSetup), strZ(pathUnitBuild)));
                 }
 
                 // Remove old coverage data. Note that coverage can be in different paths depending on the meson version.
@@ -175,12 +153,12 @@ cmdTest(
                 storageRemoveP(storageUnitBuild, STRDEF("gmon.out"));
 
                 // Ninja build
-                cmdTestExec(strNewFmt("ninja -C %s", strZ(pathUnitBuild)));
+                execOneP(strNewFmt("ninja -C '%s'", strZ(pathUnitBuild)));
                 buildRetry = false;
             }
             CATCH_ANY()
             {
-                // If this is the first build failure then clean the build path a retry
+                // If this is the first build failure then clean the build path and retry
                 if (buildRetry == false)
                 {
                     buildRetry = true;
