@@ -14,6 +14,11 @@ Control file size used to create pg_control
 ***********************************************************************************************************************************/
 #define HRN_PG_CONTROL_SIZE                                         8192
 
+/***********************************************************************************************************************************
+Default wal segment size
+***********************************************************************************************************************************/
+#define HRN_PG_WAL_SEGMENT_SIZE_DEFAULT                             ((unsigned int)(16 * 1024 * 1024))
+
 /***********************************************************************************************************************************
 System id constants by version
 ***********************************************************************************************************************************/
