@@ -13,6 +13,7 @@ Pq Test Harness
 #include "common/type/string.h"
 #include "common/type/variantList.h"
 
+#include "common/harnessFd.h"
 #include "common/harnessPq.h"
 #include "common/harnessTest.h"
 
@@ -269,6 +270,19 @@ PQisBusy(PGconn *conn)
     return hrnPqScriptRun(HRN_PQ_ISBUSY, NULL, (HrnPqScript *)conn)->resultInt;
 }
 
+/***********************************************************************************************************************************
+Shim for PQsocket()
+***********************************************************************************************************************************/
+int
+PQsocket(const PGconn *conn)
+{
+    int result = hrnPqScriptRun(HRN_PQ_SOCKET, NULL, (HrnPqScript *)conn)->resultInt;
+
+    hrnFdReadyShimOne(result == true);
+
+    return result;
+}
+
 /***********************************************************************************************************************************
 Shim for PQgetCancel()
 ***********************************************************************************************************************************/
