@@ -258,11 +258,6 @@ testRun(void)
                         "example: buffer-size=128KiB\n"
                         "example: buffer-size=256KiB</code-block>"
                     "</section>"
-                    "<section id=\"option-config\">"
-                        "<title>Config Option (<id>--config</id>)</title>"
-                        "<p>config option summary.</p>"
-                        "<p>config option description.</p>"
-                    "</section>"
                     "<section id=\"option-secure\">"
                         "<title>Secure Option (<id>--secure</id>)</title>"
                         "<p>Secure option summary.</p>"
