@@ -153,10 +153,13 @@ testRun(void)
             {.function = HRN_PQ_SENDQUERY, .param = "[\"" TEST_QUERY "\"]", .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT, .sleep = 600},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET},
             {.function = HRN_PQ_GETCANCEL},
             {.function = HRN_PQ_CANCEL, .resultInt = 1},
             {.function = HRN_PQ_FREECANCEL},
@@ -182,10 +185,13 @@ testRun(void)
             {.function = HRN_PQ_SENDQUERY, .param = "[\"" TEST_QUERY "\"]", .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT, .sleep = 300},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT, .sleep = 300},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET},
             {.function = HRN_PQ_GETCANCEL},
             {.function = HRN_PQ_CANCEL, .resultInt = 0, .resultZ = TEST_PQ_ERROR},
             {.function = HRN_PQ_FREECANCEL});
@@ -208,10 +214,13 @@ testRun(void)
             {.function = HRN_PQ_SENDQUERY, .param = "[\"" TEST_QUERY "\"]", .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT, .sleep = 600},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET, .resultInt = 1},
             {.function = HRN_PQ_CONSUMEINPUT},
             {.function = HRN_PQ_ISBUSY, .resultInt = 1},
+            {.function = HRN_PQ_SOCKET},
             {.function = HRN_PQ_GETCANCEL, .resultNull = true});
 
         TEST_ERROR(
@@ -497,8 +506,7 @@ testRun(void)
             {.function = HRN_PQ_FINISH},
             {.function = HRN_PQ_GETRESULT, .resultNull = true});
 #endif
-        TEST_RESULT_VOID(pgClientClose(client), "close client");
-        TEST_RESULT_VOID(pgClientClose(client), "close client again");
+        TEST_RESULT_VOID(pgClientFree(client), "free client");
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
